#
# K2HR3 Utilities - Get K2HR3 Resource Helper for Systemd service
#
# Copyright 2021 Yahoo Japan Corporation.
#
# K2HR3 is K2hdkc based Resource and Roles and policy Rules, gathers
# common management information for the cloud.
# K2HR3 can dynamically manage information as "who", "what", "operate".
# These are stored as roles, resources, policies in K2hdkc, and the
# client system can dynamically read and modify these information.
#
# For the full copyright and license information, please view
# the license file that was distributed with this source code.
#
# AUTHOR:   Takeshi Nakatani
# CREATE:   Wed Jan 20 2021
# REVISION:
#

#
# Local macros/define
#
%if %{undefined package_revision}
%global package_revision 1
%endif

%if %{undefined make_build}
%global make_build %{__make} %{?_smp_mflags}
%endif

%if %{undefined autosetup}
%global autosetup %setup -q
%endif

%global gittag v1.0.6

%if %{undefined make_check}
%global make_check 1
%endif

%if %{undefined not_run_autogen}
%global run_autogen ./autogen.sh
%else
%global run_autogen echo "skip autogen.sh"
%endif

#
# main package
#
Summary: Get K2HR3 Resource Helper for Systemd service
Name: k2hr3-get-resource
Version: 1.0.6
Release: %{package_revision}%{?dist}
License: MIT
Group: Applications/Other
URL: https://github.com/yahoojapan/k2hr3-get-resource
Source0: https://github.com/yahoojapan/k2hr3-get-resource/archive/%{gittag}/%{name}-%{version}.tar.gz
BuildRequires: systemd git-core make
BuildArch: noarch

%description
k2hr3-get-resource is a Systemd Timer Service for retrieving
RESOURCE data from K2HR3 System which is an RBAC System.
- Systemd timer service, which starts regularly.
- Runs on a virtual machine launched with UserDataScript by
  the K2HR3 system.
- Get K2HR3 resource related to the role for the virtual
  machine.
- Use the common directory /etc/antpickax.

%prep
%autosetup -n %{name}-%{version}

%build
%run_autogen
%configure --disable-static 
%make_build

%install
%make_install
install -D -m 644 src/k2hr3-get-resource.timer %{buildroot}/lib/systemd/system/k2hr3-get-resource.timer
install -D -m 644 src/k2hr3-get-resource.service %{buildroot}/lib/systemd/system/k2hr3-get-resource.service
install -D -m 755 src/k2hr3-get-resource-helper %{buildroot}/usr/libexec/k2hr3-get-resource-helper
install -D -m 644 src/k2hr3-get-resource-helper.conf %{buildroot}/etc/antpickax/k2hr3-get-resource-helper.conf
mkdir -p %{buildroot}/var/lib/antpickax
mkdir -p %{buildroot}/var/run/antpickax

%if %{make_check}
%check
%{__make} check
%endif

%files
%license COPYING
%doc README AUTHORS ChangeLog
/lib/systemd/system/k2hr3-get-resource.timer
/lib/systemd/system/k2hr3-get-resource.service
/usr/libexec/k2hr3-get-resource-helper
/etc/antpickax/*
%dir %attr(0777,root,root) /var/lib/antpickax
%dir %attr(0777,root,root) /var/run/antpickax

%preun
%systemd_preun k2hr3-get-resource.timer

%changelog
* Mon Mar 04 2024 Takeshi Nakatani <ggtakec@gmail.com> 1.0.6-1
- Fixed bugs in k2hr3-get-resource-helper - #26

* Mon Nov 20 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.5
- Updated build_helper.sh for fixing a bug and installing ruby - #24

* Tue Oct 31 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.4
- Changed support OS (fedora and ubuntu) and updated tool - #22

* Fri Sep 01 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.3
- Updated tool scripts and support OSs - #20
- Fixed .gitignore to exclude APKBUILD.templ - #19

* Mon Mar 06 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.2
- Updated building/packaging logic for ALPINE - #17

* Mon Feb 13 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.1
- Changed CI OSs and added Alpine OS - #15
- Updated header and footer in comment lines - #14
- Updated issue/pullrequest templates and README.md - #13
- Added ShellCheck processing - #12
- Eliminated unnecessary copies in build_helper.sh - #11
- Updated github actions process and support os, and fixed bugs - #10
- Updated debian_build.sh for grep parameter and updated configure.ac - #9
- Updated common build scripts - #8
- Updated Antpickax common scripts and tools under the buildutils directory - #7
- Separated the test files into the tests directory - #6
- Enabled external customization of configure.ac and fixed for building - #5

* Fri Mar 26 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.0
- Updated README.md for adding k2hr3 cli - #2

* Thu Jan 28 2021 Takeshi Nakatani <ggtakec@gmail.com> 0.9.0
- First version
